import parseArgs from 'minimist';
import { isInternal } from '../../util/path.js';
import { fromBinary, toBinary } from '../util.js';
export const resolve = (binary, args, { fromArgs, manifest }) => {
    const parsed = parseArgs(args, {
        '--': true,
        stopEarly: true,
        boolean: ['yes', 'no'],
        alias: { yes: 'y', no: 'no-install' },
    });
    const leftParsed = fromArgs(parsed._);
    const leftHandCommand = parsed.yes ? leftParsed.slice(1) : leftParsed;
    const rightHandCommand = parsed['--'] ? fromArgs(parsed['--']) : [];
    const binaryOrPackageName = fromBinary(leftHandCommand[0] ?? rightHandCommand[0]);
    const dependencies = manifest
        ? [...Object.keys(manifest.dependencies ?? {}), ...Object.keys(manifest.devDependencies ?? {})]
        : [];
    const dependency = !binaryOrPackageName.startsWith('@') &&
        !isInternal(binaryOrPackageName) &&
        !dependencies.includes(binaryOrPackageName)
        ? toBinary(binaryOrPackageName)
        : binaryOrPackageName;
    return [dependency, ...leftHandCommand.slice(1), ...rightHandCommand];
};
