import ts from 'typescript';
import { isImportCall, isAccessExpression, isVariableDeclarationList, findDescendants } from '../../ast-helpers.js';
import { importVisitor as visit } from '../index.js';
export default visit(() => true, node => {
    if (isImportCall(node)) {
        if (node.arguments[0] && ts.isStringLiteralLike(node.arguments[0])) {
            const specifier = node.arguments[0].text;
            if (isAccessExpression(node.parent)) {
                return { specifier, isDynamic: true };
            }
            let _ancestor = node.parent?.parent?.parent;
            if (_ancestor && isAccessExpression(_ancestor)) {
                return { specifier, isDynamic: true };
            }
            while (_ancestor) {
                if (_ancestor) {
                    if (isVariableDeclarationList(_ancestor)) {
                        return findDescendants(_ancestor, ts.isVariableDeclaration).flatMap(variableDeclaration => {
                            if (ts.isIdentifier(variableDeclaration.name)) {
                                return { identifier: 'default', specifier };
                            }
                            else {
                                const binds = findDescendants(variableDeclaration, _node => ts.isBindingElement(_node) && ts.isIdentifier(_node.name));
                                return binds.flatMap(element => {
                                    const symbol = element.propertyName?.getText() || element.name.getText();
                                    return { identifier: symbol, specifier };
                                });
                            }
                        });
                    }
                    if (ts.isPropertyAssignment(_ancestor)) {
                        return { identifier: 'default', specifier };
                    }
                }
                _ancestor = _ancestor.parent;
            }
            return { specifier };
        }
    }
});
